<?php
/**
 * Created by PhpStorm.
 * User: RSkaldin
 * Date: 6/4/2019
 * Time: 9:20 PM
 */

namespace App\Http\Controllers\Postman;

use App\Http\Controllers\Controller;
use App\Models\Activity;
use App\Models\Orders;
use App\Models\Package;
use App\Models\PackageItems;
use App\Models\Product;
use PDF;

class DeclarationController extends Controller
{
    public function index()
    {
        $packages = Package::orderBy('id', 'DESC')->paginate(25);
        $declarationJSON = $declarationJson = $this->makeDeclarationJSON($packages);

        return view('pages.admin.declarations.index', [
            'packages' => $packages,
            'declarationJSON' => $declarationJSON,
        ]);
    }

    /**
     * Generate and download declaration in PDF format
     *
     * @param $package_id
     * @return \Illuminate\Http\Response
     */
    public function generatePDF($package_id)
    {
        $package = Orders::find($package_id);
        $package_items = Product::where('order_id', $package->id)->get();
        $declaration = [];

        foreach ($package_items as $item) {
            $itemClass = new \stdClass();
            $itemClass->package_id = $package->id;
            $itemClass->name = $item->title;
            $itemClass->amount = $item->amount;
            $itemClass->price = $item->price;
            $itemClass->weight = $item->weight;

            $declaration[] = $itemClass;
        }

        $pdf = PDF::loadView('templates.declaration', [
            'title' => 'Declaration #',
            'package' => $package,
            'declaration' => $declaration,
        ]);
        $filename = md5(time()) . date('Ymdhis') . '.pdf';
        Activity::appendLog("Сгенерирована декларация в PDF формате.", Activity::NOTICE);
        return $pdf->download($filename);
    }

    /**
     * Generate Declaration about packages
     *
     * @param $packages
     * @return string
     */
    private function makeDeclarationJSON(&$packages) : string
    {
        $declaration_data = [];
        foreach ($packages as $package) {
            $package_items = PackageItems::where('package_id', $package->id)->get();
            $items_data = [];
            foreach ($package_items as $item) {
                $items_data[] =[
                    'package_id' => $package->id,
                    'name' => $item->item_name,
                    'amount' => $item->amount,
                    'price' => $item->price,
                    'weight' => $item->weight,
                    'date' => $item->date,
                ];
            }
            $declaration_data[$package->id] = $items_data;
        }

        return json_encode($declaration_data);
    }
}
